## About Apache Tamaya

Tamaya provides a flexible and powerful Configuration Solution 
for Java developers using Java SE as well as for more complex 
usage scenarios like Cloud or Java EE. It provides a modern 
type-safe property based Configuration API combined with a 
powerful environment model and a flexible SPI. 

## Features

* Unified Configuration API
* Pluggable Configuration Backends
* Enforceable Configuration Policies
* Configuration Validation and Documentation
* Seemless Enterprise Integration

## Documentation

* [Use Cases and Requirements](usecasesAnd Reqs.html)
* [High Level Design](HighLevelDesign.html)
* [API](API.html)
* [Core](Core.html)
* [Extensions](extensions.html)

---

## Quickstart

Using Apache Tamaya is simple:

1. Add `org.apache.tamaya:tamaya-core:{tamaya-version}` to your dependencies.
2. Add your config to `META-INF/javaconfiguration.properties`
3. Access your configuration by `ConfigurationProvider.getConfiguration()` and use it.
4. Look at the [extension modules](extensions.html) to customize your setup!
5. Enjoy!


## Rationale

Configuration is one of the most prominent cross-cutting concerns similar to logging. Most of us already have been
writing similar code again and again in each of our projects. Sometimes in a similar way but mostly always slightly
different, but certainly with high coupling to your configuration backends. Given your code is reused or integrated
some how, or deployed by some customers, struggling starts: not supported backends, different policies, missing
combination and validation mechanisms and so on. Tamaya solves all this by defining a common API and backend SPI.
Your code is decoupled from the configuratoin backend. There is no difference if your code is deployed on your dev box
or in a clustered Docker environment in production, it stays the same!


